@@ -4,7 +4,6 @@ General utility routines shared by various web related modules.
 
 import Cookie
 import urllib
-import time
 from datetime import datetime
 try:
     from email.utils import parsedate
@@ -14,6 +13,7 @@ except ImportError:  # Python < 2.5
 from httpexceptor import HTTP415, HTTP400, HTTP304
 
 from tiddlyweb.model.policy import PermissionsError
+from tiddlyweb.model.tiddler import timestring_to_datetime, current_timestring
 from tiddlyweb.serializer import Serializer
 from tiddlyweb.util import sha
 
@@ -177,17 +177,13 @@ def html_frame(environ, title=''):
 def http_date_from_timestamp(timestamp):
     """
     Turn a modifier or created tiddler timestamp
-    into a proper formatted HTTP date.
+    into a proper formatted HTTP date. If the timestamp
+    is invalid use now as the timestamp.
     """
     try:
-        try:
-            timestamp_datetime = datetime(*(time.strptime(timestamp,
-                '%Y%m%d%H%M')[0:6]))
-        except ValueError:
-            timestamp_datetime = datetime(*(time.strptime(timestamp,
-                '%Y%m%d%H%M%S')[0:6]))
+        timestamp_datetime = timestring_to_datetime(timestamp)
     except ValueError:
-        timestamp_datetime = datetime.utcnow()
+        timestamp_datetime = timestring_to_datetime(current_timestring())
     return timestamp_datetime.strftime('%a, %d %b %Y %H:%M:%S GMT')
 
 
